@@ -15,7 +15,7 @@ from covid_surge import Surge
 def main():
 
     # Get global surge data
-    g_surge = Surge('global')
+    g_surge = Surge(locale='global')
 
     print('# of countries: ',g_surge.cases.shape[1])
     print('# of days:      ',g_surge.cases.shape[0])
@@ -29,7 +29,7 @@ def main():
     print('*                        Single Country                            *')
     print('********************************************************************')
 
-    name = 'Spain'
+    name = 'US'
     print(name)
     print('')
 
@@ -37,7 +37,7 @@ def main():
     g_surge.plot_covid_data( name, save=True )
 
     n_last_days = 7
-    country_id = g_surge.country_names.index(name)
+    country_id = g_surge.names.index(name)
     print('')
     print('Last %i days'%n_last_days,
           ' # of cumulative cases = ', g_surge.cases[-n_last_days:,country_id])
@@ -53,14 +53,14 @@ def main():
     print('')
 
     # Plot the fit data to model function
-    g_surge.plot_covid_nlfit(name, param_vec, save=True,
-            plot_prime=True, plot_double_prime=True)
+    g_surge.plot_covid_nlfit( param_vec, name, save=True,
+            plot_prime=True, plot_double_prime=True )
 
     # Report critical times
-    (tc,dtc) = g_surge.critical_times( name, param_vec, verbose=True )
+    (tc,dtc) = g_surge.critical_times( param_vec, name, verbose=True )
 
     # Report errors 
-    g_surge.error_analysis( name, param_vec, tc, dtc )
+    g_surge.error_analysis( param_vec, tc, dtc, name )
 
     # 60-day look-ahead
     n_prediction_days = 60
@@ -70,7 +70,7 @@ def main():
 
     print('')
     print('Estimated cumulative deaths in %s days from %s = %6i'%(n_prediction_days,g_surge.dates[-1],total_deaths_predicted))
-    print('# of cumulative deaths today, %s               = %6i'%(g_surge.dates[-1],g_surge.cases[-1,g_surge.country_names.index(name)]))
+    print('# of cumulative deaths today, %s               = %6i'%(g_surge.dates[-1],g_surge.cases[-1,g_surge.names.index(name)]))
     print('')
 
 if __name__ == '__main__':
