@@ -29,7 +29,7 @@ def main():
     print('*                        Single State                              *')
     print('********************************************************************')
 
-    name = 'New York'
+    name = 'Massachusetts'
     print(name)
     print('')
 
@@ -37,7 +37,7 @@ def main():
     us_surge.plot_covid_data( name, save=True )
 
     n_last_days = 7
-    state_id = us_surge.state_names.index(name)
+    state_id = us_surge.names.index(name)
     print('')
     print('Last %i days'%n_last_days,
           ' # of cumulative cases = ', us_surge.cases[-n_last_days:,state_id])
@@ -53,14 +53,14 @@ def main():
     print('')
 
     # Plot the fit data to model function
-    us_surge.plot_covid_nlfit(name, param_vec, save=True,
+    us_surge.plot_covid_nlfit(param_vec, name, save=True,
             plot_prime=True, plot_double_prime=True)
 
     # Report critical times
-    (tc,dtc) = us_surge.critical_times( name, param_vec, verbose=True )
+    (tc,dtc) = us_surge.critical_times( param_vec, name, verbose=True )
 
     # Report errors 
-    us_surge.error_analysis( name, param_vec, tc, dtc )
+    us_surge.error_analysis( param_vec, tc, dtc, name )
 
     # 60-day look-ahead
     n_prediction_days = 60
@@ -70,7 +70,7 @@ def main():
 
     print('')
     print('Estimated cumulative deaths in %s days from %s = %6i'%(n_prediction_days,us_surge.dates[-1],total_deaths_predicted))
-    print('# of cumulative deaths today, %s               = %6i'%(us_surge.dates[-1],us_surge.cases[-1,us_surge.state_names.index(name)]))
+    print('# of cumulative deaths today, %s               = %6i'%(us_surge.dates[-1],us_surge.cases[-1,us_surge.names.index(name)]))
     print('')
 
 if __name__ == '__main__':
