@@ -14,9 +14,27 @@ import matplotlib.pyplot as plt
 
 class Surge:
 
-    def __init__(self, locale='US', log_filename='covid_surge'):
+    def __init__( self, locale='US', sub_locale=None, 
+                  save_all_original_data_html=False, 
+                  log_filename='covid_surge' ):
+        '''
+        Parameters
+        ----------
+        locale: str
+            The place data is retrieved from. Values: 'US' or 'global'.
+            US will store the states data. Global will store all countries data.
+            Default: 'US'.
+        sub_locale: str
+            The sub-place data is retrived from. This depends of `locale`.
+            If `locale` is US, then `sub_locale` must be one of the state
+            names. There is no `sub_locale` for countries.
+        '''
 
-        self.locale = locale
+        if locale=='global':
+            assert sub_locale is None
+
+        self.locale     = locale
+        self.sub_locale = sub_locale
 
         self.__end_date           = None
         self.__ignore_last_n_days = 0
@@ -26,23 +44,35 @@ class Surge:
 
         self.deaths_100k_minimum = 40 # US death per 100,000 for Chronic Lower Respiratory Diseases per year: 41 (2019)
 
-        self.state_names   = list()
-        self.populations   = None
-        self.country_names = list()
+        self.populations = None
 
         if self.locale == 'US':
-            ( state_names, populations, dates, cases ) = \
-                                                      self.__get_covid_us_data()
-            assert dates.size == cases.shape[0]
-            assert len(state_names) == cases.shape[1]
+            if self.sub_locale:
+                ( county_names, populations, dates, cases ) = \
+                self.__get_covid_us_data( self.sub_locale,
+                            save_html=save_all_original_data_html )
+
+                assert dates.size == cases.shape[0]
+                assert len(county_names) == cases.shape[1]
+
+                self.names = county_names
+
+            else:
+                ( state_names, populations, dates, cases ) = \
+                self.__get_covid_us_data( save_html=save_all_original_data_html )
+
+                assert dates.size == cases.shape[0]
+                assert len(state_names) == cases.shape[1]
+
+
+                self.names = state_names
 
-            self.state_names = state_names
             self.populations = populations
 
         elif self.locale == 'global':
             ( country_names, dates, cases ) = \
                                    self.__get_covid_global_data(cumulative=True)
-            self.country_names = country_names
+            self.names = country_names
 
         else:
             assert False, 'Bad locale: %r (US, global)'%(self.locale)
@@ -58,6 +88,7 @@ class Surge:
 
         self.cases = np.copy(self.__cases)
         self.dates = np.copy(self.__dates)
+
         return
 
     def __set_end_date(self, v):
@@ -69,6 +100,7 @@ class Surge:
 
         if self.__end_date is not None:
             assert isinstance(self.__end_date,str)
+            assert isinstance(self.__cases,np.ndarray)
             (id,) = np.where(self.dates==self.__end_date)
             assert id.size == 1
             self.dates = np.copy(self.dates[:id[0]+1])
@@ -105,7 +137,8 @@ class Surge:
         return self.__ignore_last_n_days
     ignore_last_n_days = property(__get_ignore_last_n_days, __set_ignore_last_n_days, None, None)
 
-    def __get_covid_us_data(self, type='deaths', save_html=False ):
+    def __get_covid_us_data(self, sub_locale=None, 
+            case_type='deaths', save_html=False ):
         '''
         Load COVID-19 pandemic cumulative data from:
 
@@ -113,7 +146,7 @@ class Surge:
 
         Parameters
         ----------
-        type:  str, optional
+        case_type:  str, optional
                 Type of data. Deaths ('deaths') and confirmed cases ('confirmed').
                 Default: 'deaths'.
 
@@ -126,13 +159,13 @@ class Surge:
 
         import pandas as pd
 
-        if type == 'deaths':
+        if case_type == 'deaths':
 
             df = pd.read_csv('https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_US.csv')
             if save_html:
                 df.to_html('covid_19_deaths.html')
 
-        elif type == 'confirmed':
+        elif case_type == 'confirmed':
 
             df = pd.read_csv('https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_confirmed_US.csv')
             df_pop = pd.read_csv('https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_US.csv')
@@ -140,21 +173,20 @@ class Surge:
                 df.to_html('covid_19_confirmed.html')
 
         else:
-            assert True, 'invalid query type: %r (valid: "deaths", "confirmed"'%(type)
+            assert True, 'invalid query type: %r (valid: "deaths", "confirmed"'%(case_type)
 
         df = df.drop(['UID','iso2','iso3','Combined_Key','code3','FIPS','Lat', 'Long_','Country_Region'],axis=1)
 
-        df = df.rename(columns={'Province_State':'state/province','Admin2':'city'})
-
-        import numpy as np
+        df = df.rename(columns={'Province_State':'state/province','Admin2':'county'})
 
         state_names = list()
-
         state_names_tmp = list()
 
         for (i,istate) in enumerate(df['state/province']):
-            if istate.strip() == 'Wyoming' and df.loc[i,'city']=='Weston':
+
+            if istate.strip() == 'Wyoming' and df.loc[i,'county']=='Weston':
                 break
+
             state_names_tmp.append(istate)
 
         state_names_set = set(state_names_tmp)
@@ -164,24 +196,82 @@ class Surge:
 
         dates = np.array(list(df.columns[3:]))
 
-        population = [0]*len(state_names)
-        cases = np.zeros( (len(df.columns[3:]),len(state_names)), dtype=np.float64)
+        if sub_locale is None:
 
-        for (i,istate) in enumerate(df['state/province']):
-            if istate.strip() == 'Wyoming' and df.loc[i,'city']=='Weston':
-                break
+            population = [0]*len(state_names)
 
-            state_id = state_names.index(istate)
-            if type == 'confirmed':
-                population[state_id] += int(df_pop.loc[i,'Population'])
-            else:
-                population[state_id] += int(df.loc[i,'Population'])
+            cases = np.zeros( (len(df.columns[3:]), len(state_names)),
+                    dtype=np.float64)
 
-            cases[:,state_id] += np.array(list(df.loc[i, df.columns[3:]]))
+            for (i,istate) in enumerate(df['state/province']):
 
-        return ( state_names, population, dates, cases )
+                if istate.strip() == 'Wyoming' and\
+                    (df.loc[i,'county']).strip() == 'Weston':
+                    break
 
-    def __get_covid_global_data(self, type='deaths', 
+                state_id = state_names.index(istate)
+
+                if case_type == 'confirmed':
+                    population[state_id] += int(df_pop.loc[i,'Population'])
+                else:
+                    population[state_id] += int(df.loc[i,'Population'])
+
+                # Add all counties/city/towns columnwise states
+                cases[:,state_id] += np.array(list(df.loc[i, df.columns[3:]]))
+
+            return ( state_names, population, dates, cases )
+
+        elif sub_locale in state_names:
+
+            county_names = list()
+            county_names_tmp = list()
+
+            for (i,istate) in enumerate(df['state/province']):
+
+                if istate.strip()=='Wyoming' and df.loc[i,'county']=='Weston':
+                    break
+
+                if istate.strip() == sub_locale:
+
+                    county_names_tmp.append( df.loc[i,'county'] )
+
+            county_names_set = set(county_names_tmp)
+
+            county_names = list(county_names_set)
+            county = sorted(county_names)
+
+            population = [0]*len(county_names)
+
+            cases = np.zeros( (len(df.columns[3:]), len(county_names)),
+                    dtype=np.float64)
+
+            for (i,istate) in enumerate(df['state/province']):
+
+                if istate.strip()=='Wyoming' and df.loc[i,'county']=='Weston':
+                    break
+
+                icounty = df.loc[i,'county']
+
+                if istate.strip() == sub_locale:
+
+                    county_id = county_names.index(icounty)
+
+                    if case_type == 'confirmed':
+                        population[county_id] += int(df_pop.loc[i,'Population'])
+                    else:
+                        population[county_id] += int(df.loc[i,'Population'])
+
+                    cases[:,county_id] = np.array(
+                            list(df.loc[i, df.columns[3:]]) )
+
+            return ( county_names, population, dates, cases )
+
+        else:
+            assert sub_locale in state_names,\
+                    '\n\n sub_locale %r not in %r'%(sub_locale,state_names)
+
+
+    def __get_covid_global_data(self, case_type='deaths', 
             distribution=True, cumulative=False, save_html=False ):
         '''
         Load COVID-19 pandemic cumulative data from:
@@ -190,7 +280,7 @@ class Surge:
 
         Parameters
         ----------
-        type: str, optional
+        case_type: str, optional
             Type of data. Deaths ('deaths') and confirmed cases ('confirmed').
             Default: 'deaths'.
 
@@ -214,13 +304,13 @@ class Surge:
 
         import pandas as pd
 
-        if type == 'deaths':
+        if case_type == 'deaths':
             df = pd.read_csv('https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_global.csv')
             if save_html:
                 df.to_html('covid_19_global_deaths.html')
 
         else:
-            assert True, 'invalid query type: %r (valid: "deaths"'%(type)
+            assert True, 'invalid query type: %r (valid: "deaths"'%(case_type)
 
         df = df.drop(['Lat', 'Long'],axis=1)
         df = df.rename(columns={'Province/State':'state/province','Country/Region':'country/region'})
@@ -256,23 +346,23 @@ class Surge:
 
         return ( country_names, dates, cases )
 
-    def plot_covid_data(self, name, save=False):
+    def plot_covid_data(self, name=None, save=False):
 
         population = None
 
-        if name == 'US' and self.locale == 'US':
-            # Combine all column data in the surge
+        if name is None: # Combine all column data in the surge
             cases_plot = np.sum(self.cases,axis=1)
-            population = np.sum(self.populations)
-        elif name in self.state_names:
-            state_id = self.state_names.index(name)
-            population = self.populations[state_id]
-            cases_plot = self.cases[:,state_id]
-        elif name in self.country_names:
-            country_id = self.country_names.index(name)
-            cases_plot = self.cases[:,country_id]
+            if self.populations:
+                population = np.sum(self.populations)
+        elif name in self.names:
+            name_id = self.names.index(name)
+            if self.populations:
+                population = self.populations[name_id]
+            cases_plot = self.cases[:,name_id]
         else:
-            assert name in self.state_names or name in self.country_names, 'Name: %r not in %r or %r'%(name,self.state_names,self.country_names)
+            assert name in self.names,\
+            '\n\n Name: %r not in %r'%(name,self.names)
+
 
         # Select data with # of cases greater than the minimum
         (nz_cases_ids,) = np.where(cases_plot>self.min_n_cases_rel/100*cases_plot[-1])
@@ -289,11 +379,15 @@ class Surge:
         xlabel = 'Date'
         ylabel = 'Cumulative Deaths []'
 
+        if name is None:
+            locale = self.locale+' Combined '
+        else:
+            locale = name
         if population:
-            title = 'COVID-19 in '+name+'; population: '+str(population)+\
+            title = 'COVID-19 in '+locale+'; population: '+str(population)+\
                     '; deaths per 100k/y: '+str(deaths_100k_y)
         else:
-            title = 'COVID-19 in '+name
+            title = 'COVID-19 in '+locale
 
         source = 'Johns Hopkins CSSE: https://github.com/CSSEGISandData/COVID-19'
 
@@ -312,37 +406,29 @@ class Surge:
         plt.grid(True)
         plt.tight_layout(1)
 
-        filename = name.lower().strip().split(' ')
-        if len(filename) == 1:
-            filename = filename[0]
-        else:
-            tmp = filename[0]
-            for (i,v) in enumerate(filename):
-                if i == 0:
-                    continue
-                tmp = tmp+'_'+v
-            filename = tmp
-
         plt.show()
         if save:
-            plt.savefig('data_'+filename+'.png', dpi=100)
+            from covid_surge import filename
+            if self.sub_locale is None:
+                stem = filename(self.locale)
+            else:
+                stem = filename(self.locale+'_'+self.sub_locale)
+            stem += '_'+filename(locale)
+            plt.savefig('data_'+stem+'.png', dpi=100)
         plt.close()
 
         return
 
-    def fit_data(self, name ):
+    def fit_data(self, name=None):
 
-        if name == 'US' and self.locale == 'US':
-            # Combine all column data in the surge
-            cases      = np.sum(self.cases,axis=1)
-        elif name in self.state_names:
-            state_id = self.state_names.index(name)
-            cases = self.cases[:,state_id]
-        elif name in self.country_names:
-            country_id = self.country_names.index(name)
-            cases = self.cases[:,country_id]
+        if name is None: # Combine all column data in the surge
+            cases = np.sum(self.cases,axis=1)
+        elif name in self.names:
+            name_id = self.names.index(name)
+            cases = self.cases[:,name_id]
         else:
-            assert name in self.state_names or name in self.country_names, 'Name: %r not in %r or %r'%(name,self.state_names,self.country_names)
+            assert name in self.names,\
+                '\n\n Name: %r not in %r'%(name,self.names)
 
         # Select data with # of cases greater than the minimum
         (nz_cases_ids,) = np.where(cases>self.min_n_cases_rel/100*cases[-1])
@@ -380,7 +466,7 @@ class Surge:
 
         return param_vec
 
-    def plot_covid_nlfit(self, name, param_vec, 
+    def plot_covid_nlfit(self, param_vec, name=None, 
             save=False, plot_prime=False, plot_double_prime=False,
             option='dates', ylabel='null-ylabel',
             legend='null-legend', title='null-title', formula='null-formula'):
@@ -389,19 +475,18 @@ class Surge:
 
         population = None
 
-        if name == 'US' and self.locale == 'US':
-            # Combine all column data in the surge
+        if name is None: # Combine all column data in the surge
             cases_plot = np.sum(self.cases,axis=1)
-            population = np.sum(self.populations)
-        elif name in self.state_names:
-            state_id = self.state_names.index(name)
-            population = self.populations[state_id]
-            cases_plot = self.cases[:,state_id]
-        elif name in self.country_names:
-            country_id = self.country_names.index(name)
-            cases_plot = self.cases[:,country_id]
+            if self.populations:
+                population = np.sum(self.populations)
+        elif name in self.names:
+            name_id = self.names.index(name)
+            if self.populations:
+                population = self.populations[name_id]
+            cases_plot = self.cases[:,name_id]
         else:
-            assert name in self.state_names or name in self.country_names, 'Name: %r not in %r or %r'%(name,self.state_names,self.country_names)
+            assert name in self.names,\
+                '\n\n Name: %r not in %r'%(name,self.names)
 
         # Select data with # of cases greater than the minimum
         (nz_cases_ids,) = np.where(cases_plot>self.min_n_cases_rel/100*cases_plot[-1])
@@ -416,11 +501,15 @@ class Surge:
                     cases_plot[-1]*100000/population * 365/cases_plot.size, 1
                              )
 
+        if name is None:
+            locale = self.locale+' Combined '
+        else:
+            locale = name
         if population:
-            title = 'COVID-19 in '+name+'; population: '+str(population)+\
+            title = 'COVID-19 in '+locale+'; population: '+str(population)+\
                 '; deaths per 100k/y: '+str(deaths_100k_y)
         else:
-            title = 'COVID-19 in '+name
+            title = 'COVID-19 in '+locale
 
         source = 'Johns Hopkins CSSE: https://github.com/CSSEGISandData/COVID-19'
 
@@ -436,7 +525,7 @@ class Surge:
 
         cases_fit = self.sigmoid_func( dates_fit, param_vec )
 
-        plt.plot( dates_fit,cases_fit,'b-',label='covid-surge fitting' )
+        plt.plot( dates_fit,cases_fit,'b-',label='Covid-surge fitting' )
 
         if option == 'dates':
             plt.xticks( range(len(dates_plot)),dates_plot,rotation=60,fontsize=14)
@@ -449,7 +538,7 @@ class Surge:
         plt.ylabel(ylabel,fontsize=16)
         plt.title(title,fontsize=20)
 
-        (tc,dtc) = self.critical_times(name,param_vec,verbose=False)
+        (tc,dtc) = self.critical_times(param_vec,name,verbose=False)
 
         time_max_prime = tc
         time_min_max_double_prime = [tc-dtc,tc+dtc]
@@ -528,20 +617,15 @@ class Surge:
         plt.grid(True)
         plt.tight_layout(1)
 
-        filename = name.lower().strip().split(' ')
-        if len(filename) == 1:
-            filename = filename[0]
-        else:
-            tmp = filename[0]
-            for (i,v) in enumerate(filename):
-                if i == 0:
-                    continue
-                tmp = tmp+'_'+v
-            filename = tmp
-
         plt.show()
         if save:
-            plt.savefig('data_fit_'+filename+'_0'+'.png', dpi=100)
+            from covid_surge import filename
+            if self.sub_locale is None:
+                stem = filename(self.locale)
+            else:
+                stem = filename(self.locale+'_'+self.sub_locale)
+            stem += '_'+filename(locale)
+            plt.savefig('fit_'+stem+'_0'+'.png', dpi=100)
 
         plt.close()
 
@@ -569,7 +653,7 @@ class Surge:
 
             cases_fit = fit_func_prime( dates_fit, param_vec )
 
-            plt.plot(dates_fit,cases_fit,'b-',label='Fitting derivative' )
+            plt.plot(dates_fit,cases_fit,'b-',label='Covid-surge fitting derivative' )
 
             if time_max_prime is not None:
 
@@ -593,20 +677,15 @@ class Surge:
             plt.legend(loc='best',fontsize=12)
             plt.tight_layout(1)
 
-            filename = name.lower().strip().split(' ')
-            if len(filename) == 1:
-                filename = filename[0]
-            else:
-                tmp = filename[0]
-                for (i,v) in enumerate(filename):
-                    if i == 0:
-                        continue
-                    tmp = tmp+'_'+v
-                filename = tmp
-
             plt.show()
             if save:
-                plt.savefig('fit_'+filename+'_1'+'.png', dpi=100)
+                from covid_surge import filename
+                if self.sub_locale is None:
+                    stem = filename(self.locale)
+                else:
+                    stem = filename(self.locale+'_'+self.sub_locale)
+                stem += '_'+filename(locale)
+                plt.savefig('fit_'+stem+'_1'+'.png', dpi=100)
             plt.close()
 
         # Additional plot for second derivative 
@@ -665,20 +744,15 @@ class Surge:
             plt.grid(True)
             plt.tight_layout(1)
 
-            filename = name.lower().strip().split(' ')
-            if len(filename) == 1:
-                filename = filename[0]
-            else:
-                tmp = filename[0]
-                for (i,v) in enumerate(filename):
-                    if i == 0:
-                        continue
-                    tmp = tmp+'_'+v
-                filename = tmp
-
             plt.show()
             if save:
-                plt.savefig('fit_'+filename+'_2'+'.png', dpi=100)
+                from covid_surge import filename
+                if self.sub_locale is None:
+                    stem = filename(self.locale)
+                else:
+                    stem = filename(self.locale+'_'+self.sub_locale)
+                stem += '_'+filename(locale)
+                plt.savefig('fit_'+stem+'_2.png', dpi=100)
             plt.close()
 
         return
@@ -861,7 +935,7 @@ class Surge:
 
         return (param_vec, r2, k)
 
-    def critical_times(self, name, param_vec, verbose=False):
+    def critical_times(self, param_vec, name=None, verbose=False):
 
         a0 = param_vec[0]
         a1 = param_vec[1]
@@ -869,18 +943,16 @@ class Surge:
 
         import math
 
-        if name == 'US' and self.locale == 'US':
-            # Combine all column data in the surge
+        if name is None: # Combine all column data in the surge
             cases = np.sum(self.cases,axis=1)
-        elif name in self.state_names:
-            state_id = self.state_names.index(name)
-            population = self.populations[state_id]
-            cases = self.cases[:,state_id]
-        elif name in self.country_names:
-            country_id = self.country_names.index(name)
-            cases = self.cases[:,country_id]
+        elif name in self.names:
+            name_id = self.names.index(name)
+            if self.populations:
+                population = self.populations[name_id]
+            cases = self.cases[:,name_id]
         else:
-            assert name in self.state_names or name in self.country_names, 'Name: %r not in %r or %r'%(name,self.state_names,self.country_names)
+            assert name in self.names, \
+              '\n\n Name: %r not in %r'%(name,self.names)
 
         # Select data with non-zero cases only
         (nz_cases_ids,) = np.where(cases>0)
@@ -982,22 +1054,20 @@ class Surge:
 
         assert abs( a0*a2**2*(5+3*math.sqrt(3))/(3+math.sqrt(3))**3 - sigmoid_func_double_prime(time_max_double_prime,param_vec) ) <= 1.e-8
 
-    def error_analysis(self, name, param_vec, tc, dtc):
+    def error_analysis(self, param_vec, tc, dtc, name=None):
 
         population = None
 
-        if name == 'US' and self.locale == 'US':
-            # Combine all column data in the surge
+        if name is None: # Combine all column data in the surge
             cases = np.sum(self.cases,axis=1)
-        elif name in self.state_names:
-            state_id = self.state_names.index(name)
-            population = self.populations[state_id]
-            cases = self.cases[:,state_id]
-        elif name in self.country_names:
-            country_id = self.country_names.index(name)
-            cases = self.cases[:,country_id]
+        elif name in self.names:
+            name_id = self.names.index(name)
+            if self.populations:
+                population = self.populations[name_id]
+            cases = self.cases[:,name_id]
         else:
-            assert name in self.state_names or name in self.country_names, 'Name: %r not in %r or %r'%(name,self.state_names,self.country_names)
+            assert name in self.names,\
+                 'Name: %r not in %r'%(name,self.names)
 
         # Select data with # of cases greater than the minimum
         (nz_cases_ids,) = np.where(cases>self.min_n_cases_rel/100*cases[-1])
@@ -1054,17 +1124,11 @@ class Surge:
 
         return
 
-    def multi_fit_data(self, name, 
+    def multi_fit_data(self, 
             blocked_list=[],
             verbose=False, plot=False, save_plots=False):
 
-        if name == 'states':
-            names = self.state_names
-        elif name == 'countries':
-            names = self.country_names
-        else:
-            assert False,'Bad name %r (states or countries)'%name
-
+        names = self.names
         cases = self.cases
 
         # Sort the states by descending number of total cases
@@ -1174,13 +1238,16 @@ class Surge:
                 print('')
 
             # Compute critical times
-            (tc,dtc) = self.critical_times(name,param_vec,verbose=verbose)
+            (tc,dtc) = self.critical_times(param_vec,name,verbose=verbose)
 
             if tc > times[-1]:
                 if verbose:
                     print('')
                     print('WARNING: Time at peak surge rate exceeds time data.')
                     print('WARNING: Skipping this data set.')
+                assert int(tc-dtc)+1 <= dates.size,\
+                        '\n\n value = %r; dates.sizes = %r; times.size = %r'%(int(tc-dtc)+1,dates.size,times.size)
+
                 names_no_peak_surge_period.append( (name, tc-dtc, dates[int(tc-dtc)+1], dtc) )
                 continue
 
@@ -1189,6 +1256,8 @@ class Surge:
                     print('')
                     print('WARNING: Time at mininum acceleration exceeds time data.')
                     print('WARNING: Skipping this data set.')
+                assert int(tc)+1 <= dates.size,\
+                        '\n\n value = %r; dates.sizes = %r; times.size = %r'%(int(tc)+1,dates.size,times.size)
                 names_past_peak_surge_period.append( (name, tc, dates[int(tc)+1], dtc) )
                 continue
 
@@ -1197,7 +1266,7 @@ class Surge:
 
 
             if plot:
-                self.plot_covid_nlfit( name, param_vec, save=save_plots )
+                self.plot_covid_nlfit( param_vec, name, save=save_plots )
 
 
             n_last_days = 7
@@ -1214,7 +1283,7 @@ class Surge:
 
             # Report erros
             if verbose:
-                self.error_analysis(name, param_vec, tc, dtc)
+                self.error_analysis(param_vec, tc, dtc, name)
 
             # 60-day look-ahead
             n_prediction_days = 60
@@ -1259,7 +1328,7 @@ class Surge:
 
             print('')
 
-            print('States with deaths below the absolute mininum:')
+            print('Names with deaths below the absolute mininum:')
             print('')
             for (name, case) in names_below_deaths_abs_minimum:
                 print( '%15s deaths = %5.2f'%(name,case) )
@@ -1276,6 +1345,12 @@ class Surge:
 
         sorted_fit_data = sorted_by_surge_period
 
+        if verbose:
+            print('')
+            for (sort_key,data) in sorted_fit_data:
+                name = data[0]
+                print('%15s: surge period %1.2f [day]'%(name,sort_key))
+
         return sorted_fit_data
 
     def plot_multi_fit_data(self, fit_data, option=None, save=False):
@@ -1312,19 +1387,26 @@ class Surge:
 
             ax1.grid(True)
 
-            (key,data)=fit_data[0]
-            if data[0] in self.state_names:
+            data_name = 'null-data-name'
+            if self.locale == 'US' and self.sub_locale is None:
                 data_name = 'US States'
-            if data[0] in self.country_names:
+            if self.locale == 'US' and self.sub_locale != None:
+                data_name = self.sub_locale+' Counties/Cities'
+            elif self.locale == 'global':
                 data_name = 'Countries'
 
             plt.title('COVID-19 Pandemic 2020 for Top '+
-                str(len(fit_data))+' '+data_name+' in Evolved Mortality ('+
+                str(len(fit_data))+' '+data_name+' w/ Evolved Mortality ('+
                 data[1][-1]+')',fontsize=20)
 
             plt.show()
             if save:
-                plt.savefig('data_overlap'+'_0'+'.png', dpi=100)
+                from covid_surge import filename
+                if self.sub_locale is None:
+                    stem = filename(self.locale)
+                else:
+                    stem = filename(self.locale+'_'+self.sub_locale)
+                plt.savefig('data_'+stem+'_overlap'+'.png', dpi=100)
             plt.close()
 
 
@@ -1364,19 +1446,26 @@ class Surge:
 
             ax1.grid(True)
 
-            (key,data)=fit_data[0]
-            if data[0] in self.state_names:
+            data_name = 'null-data-name'
+            if self.locale == 'US' and self.sub_locale is None:
                 data_name = 'US States'
-            if data[0] in self.country_names:
+            if self.locale == 'US' and self.sub_locale != None:
+                data_name = self.sub_locale+' Counties/Cities'
+            elif self.locale == 'global':
                 data_name = 'Countries'
 
             plt.title('COVID-19 Pandemic 2020 for Top '+
-                str(len(fit_data))+' '+data_name+' in Evolved Mortality ('+
+                str(len(fit_data))+' '+data_name+' w/ Evolved Mortality ('+
                 data[1][-1]+')',fontsize=20)
 
             plt.show()
             if save:
-                plt.savefig('fit_overlap'+'_1'+'.png', dpi=100)
+                from covid_surge import filename
+                if self.sub_locale is None:
+                    stem = filename(self.locale)
+                else:
+                    stem = filename(self.locale+'_'+self.sub_locale)
+                plt.savefig('fit_'+stem+'_overlap'+'.png', dpi=100)
             plt.close()
 
         return
@@ -1474,19 +1563,26 @@ class Surge:
 
             ax1.grid(True)
 
-            (key,data)=fit_data[0]
-            if data[0] in self.state_names:
+            data_name = 'null-data-name'
+            if self.locale == 'US' and self.sub_locale is None:
                 data_name = 'US States'
-            if data[0] in self.country_names:
+            if self.locale == 'US' and self.sub_locale != None:
+                data_name = self.sub_locale+' Counties/Cities'
+            elif self.locale == 'global':
                 data_name = 'Countries'
 
             plt.title('COVID-19 Pandemic 2020 for Top '+
-                str(len(fit_data))+' '+data_name+' in Evolved Mortality ('+
+                str(len(fit_data))+' '+data_name+' w/ Evolved Mortality ('+
                 data[1][-1]+')',fontsize=20)
 
             plt.show()
             if save:
-                plt.savefig('fit_group_'+str(ig)+'.png', dpi=100)
+                from covid_surge import filename
+                if self.sub_locale is None:
+                    stem = filename(self.locale)
+                else:
+                    stem = filename(self.locale+'_'+self.sub_locale)
+                plt.savefig('fit_group_'+str(ig)+'_'+stem+'.png', dpi=100)
             plt.close()
 
         return
@@ -1552,21 +1648,30 @@ class Surge:
         ax.set_ylabel('Surge Period [day]',fontsize=16)
         ax.set_xlabel('',fontsize=20)
         ax.xaxis.grid(True,linestyle='-',which='major',color='lightgrey',alpha=0.9)
-        (key,data)=fit_data[0]
-        if data[0] in self.state_names:
+
+        data_name = 'null-data-name'
+        if self.locale == 'US' and self.sub_locale is None:
             data_name = 'US States'
-        if data[0] in self.country_names:
+        if self.locale == 'US' and self.sub_locale != None:
+            data_name = self.sub_locale+' Counties/Cities'
+        elif self.locale == 'global':
             data_name = 'Countries'
 
         plt.title('COVID-19 Pandemic 2020 for Top '+
-            str(len(fit_data))+' '+data_name+' in Evolved Mortality ('+
+            str(len(fit_data))+' '+data_name+' w/ Evolved Mortality ('+
             data[1][-1]+')',fontsize=20)
 
         plt.tight_layout(1)
 
         plt.show()
         if save:
-            plt.savefig('group_surge_periods.png', dpi=100)
+            from covid_surge import filename
+            if self.sub_locale is None:
+                stem = filename(self.locale)
+            else:
+                stem = filename(self.locale+'_'+self.sub_locale)
+            plt.savefig('group_surge_periods_'+stem+'.png', dpi=100)
         plt.close()
 
         return
+
